@@ -123,8 +123,8 @@ class WOQLQuery:
                         c = {"@value": c}
                     clauses.append({'as': [c, v]})
                 else:
-                    if hasattr(v, 'woql_as') or ('as' in v):
-                        clauses += v.json()
+                    if hasattr(a, 'as') or ('as' in a):
+                        clauses.append(v)
                     else:
                         clauses.append({'as': [v]})
         return clauses
@@ -206,13 +206,14 @@ class WOQLQuery:
         self.cursor['length'] = [va, vb];
         return self
 
-    def remote(self, url, opts=None):
+    def remote(self, json, opts=None):
         """Provides details of a remote data source in a JSON format that includes a URL property
 
         Parameters
         ----------
-        url : remote data source url
-        opts : input options, optional
+        json : dict
+            remote data source in a JSON format
+        opts : imput options, optional
 
         Returns
         -------
@@ -220,32 +221,10 @@ class WOQLQuery:
             query object that can be chained and/or execute
         """
         if opts is not None:
-            self.cursor['remote'] = [url, opts]
-        else:
-            self.cursor['remote'] = [url]
+            self.cursor['remote'] = [json, opts]
+        self.cursor['remote'] = [json];
         return self
 
-    def post(self, field, opts=None):
-        """Provides details of a file source in a JSON format that includes a URL property
-
-        Parameters
-        ----------
-        fileName : str
-            field
-        opts : input options, optional
-
-        Returns
-        -------
-        WOQLQuery object
-            query object that can be chained and/or execute
-        """
-        if opts is not None:
-            self.cursor['post'] = [field, opts]
-        else:
-            self.cursor['post'] = [field]
-        return self
-
-
     def file(self, json, opts=None):
         """Provides details of a file source in a JSON format that includes a URL property
 
@@ -262,8 +241,7 @@ class WOQLQuery:
         """
         if opts is not None:
             self.cursor['file'] = [json, opts]
-        else:
-            self.cursor['file'] = [json]
+        self.cursor['file'] = [json];
         return self
 
     def group_by(self, gvarlist, groupedvar, groupquery, output=None):
@@ -473,12 +451,12 @@ class WOQLQuery:
         self.cursor['re'] = [pattern, test, matches]
         return self
 
-    def concat(self, lst, v):
+    def concat(self, list, v):
         """Concatenates the list of variables into a string and saves the result in v
 
         Parameters
         ----------
-        lst : list
+        list : list
             list of variables to concatenate
         v : str
             saves the results
@@ -488,17 +466,17 @@ class WOQLQuery:
         WOQLQuery object
             query object that can be chained and/or execute
         """
-        if type(lst) == str:
-            nlist = re.split('(v:[\w_]+)\\b', lst)
+        if type(list) == str:
+            nlist = re.split('(v:[\w_]+)\\b', list)
             for i in range(1,len(nlist)):
                 if (nlist[i-1][len(nlist[i-1])-1:] == "v") and \
                    (nlist[i][:1] == ":"):
                    nlist[i-1] = nlist[i-1][:len(nlist[i-1])-1]
                    nlist[i] = nlist[i][1:]
-        elif 'list' in lst:
-            nlist = lst['list']
-        elif isinstance(lst, (list, dict, WOQLQuery)):
-            nlist = lst
+        elif 'list' in list:
+            nlist = list['list']
+        elif isinstance(list, (list, dict, WOQLQuery)):
+            nlist = list
         args = []
         for item in nlist:
             if (not item):
@@ -510,7 +488,7 @@ class WOQLQuery:
                     nvalue = {"@value": item, "@type": "xsd:string"}
                     args.append(nvalue)
             elif item:
-                args.append(item)
+                args.append(nlist[i])
 
         if v.find(":") == -1:
             v = "v:" + v
@@ -670,7 +648,6 @@ class WOQLQuery:
         if json:
             self.query = json
             return self
-
         return self.query
 
     def when(self, Query, Update=None):
@@ -2365,7 +2342,7 @@ class WOQLQuery:
 
     def _is_chainable(self, operator, lastArg=None):
         """Determines whether a given operator can have a chained query as its last argument"""
-        non_chaining_operators = ["and", "or", "remote", "file", "re","post"]
+        non_chaining_operators = ["and", "or", "remote", "file", "re"]
         if (lastArg is not None and type(lastArg) == dict and
             '@value' not in lastArg and
             '@type' not in lastArg and
@@ -2378,23 +2355,21 @@ class WOQLQuery:
         else:
             return False
 
-    def execute(self, client, fileList=None):
+    def execute(self, client):
         """Executes the query using the passed client to connect to a server
 
         Parameters
         ----------
         client : woqlClient
         """
-        
         if "@context" not in self.query:
             self.query['@context'] = self._default_context(client.conConfig.dbURL())
         json = self.json()
         if self.contains_update:
-            #return client.select(json)
-            return client.update(json,None,None,fileList)
+            return client.select(json)
+            #return client.update(json)
         else:
-            #return client.select(json)
-            return client.update(json,None,None,fileList)
+            return client.select(json)
 
 
 class TripleBuilder:
